@@ -2,7 +2,13 @@ import logging
 from typing import Union, List
 
 from getdeck.configuration import ClientConfiguration
-from getdeck.deckfile.file import DeckfileHelmSource, DeckfileDirectorySource, Deckfile
+from getdeck.deckfile.file import (
+    DeckfileHelmSource,
+    DeckfileDirectorySource,
+    Deckfile,
+    DeckfileFileSource,
+)
+from getdeck.sources.file import generate_file_source
 from getdeck.sources.helm import generate_helm_source
 from getdeck.sources.types import GeneratedDeck, K8sSourceFile
 
@@ -11,11 +17,17 @@ logger = logging.getLogger("deck")
 
 def fetch_deck_source(
     config: ClientConfiguration,
-    source: Union[DeckfileHelmSource, DeckfileDirectorySource],
+    source: Union[DeckfileFileSource, DeckfileHelmSource, DeckfileDirectorySource],
     namespace: str = "default",
 ) -> List[K8sSourceFile]:
-    if isinstance(source, DeckfileHelmSource):
+    logger.info(
+        "Processing source "
+        f"{source.__class__.__name__}: {'no ref' if not source.ref else source.ref}"
+    )
+    if type(source) == DeckfileHelmSource:
         return generate_helm_source(config, source, namespace)
+    if type(source) == DeckfileFileSource:
+        return generate_file_source(config, source, namespace)
 
 
 def prepare_k8s_workload_for_deck(
@@ -28,6 +40,5 @@ def prepare_k8s_workload_for_deck(
     generated_deck = GeneratedDeck(name=deck.name, namespace=namespace, files=[])
     logger.info(f"Processing {len(deck.sources)} source(s)")
     for source in deck.sources:
-        logger.info(f"Processing source {source.ref}")
         generated_deck.files.extend(fetch_deck_source(config, source, namespace))
     return generated_deck
